@@ -26,24 +26,27 @@ Module for DocLayNet dataset. Place the dataset as follows
     │ ├── 0a0d43e301facee9e99cc33b9b16e732dd207135f4027e75f6aea2bf117535a2.png
 """
 
+from __future__ import annotations
+
 import os
 from typing import Mapping, Sequence, Union
 
 from ...dataflow import DataFlow, MapData, MapDataComponent, SerializerCoco
-from ...datapoint.annotation import CategoryAnnotation, SummaryAnnotation
+from ...datapoint.annotation import CategoryAnnotation
 from ...datapoint.image import Image
 from ...mapper.cats import add_summary, cat_to_sub_cat, filter_cat, filter_summary
 from ...mapper.cocostruct import coco_to_image
 from ...mapper.maputils import curry
-from ...utils.detection_types import JsonDict
 from ...utils.fs import load_image_from_file
-from ...utils.settings import DatasetType, DocumentType, LayoutType, ObjectTypes, PageType, TypeOrStr
+from ...utils.settings import DatasetType, DocumentType, LayoutType, ObjectTypes, PageType, SummaryType, TypeOrStr
+from ...utils.types import CocoDatapointDict
 from ..base import DatasetBase
 from ..dataflow_builder import DataFlowBaseBuilder
 from ..info import DatasetCategories, DatasetInfo
 from ..registry import dataset_registry
 
 _NAME = "doclaynet"
+_SHORT_DESCRIPTION = "DocLayNet is a human-annotated document layout segmentation dataset containing 80863 pages."
 _DESCRIPTION = (
     "DocLayNet is a human-annotated document layout segmentation dataset containing 80863 pages from a broad "
     "variety of document sources. \n"
@@ -63,59 +66,67 @@ _DESCRIPTION = (
 _LICENSE = "CDLA-Permissive"
 _URL = "https://codait-cos-dax.s3.us.cloud-object-storage.appdomain.cloud/dax-doclaynet/1.0.0/DocLayNet_core.zip"
 _SPLITS: Mapping[str, str] = {"train": "train", "val": "val", "test": "test"}
-_TYPE = DatasetType.object_detection
+_TYPE = DatasetType.OBJECT_DETECTION
 
 _LOCATION = "DocLayNet_core"
 
 _ANNOTATION_FILES: Mapping[str, str] = {"train": "COCO/train.json", "val": "COCO/val.json", "test": "COCO/test.json"}
 _INIT_CATEGORIES = [
-    LayoutType.caption,
-    LayoutType.footnote,
-    LayoutType.formula,
-    LayoutType.list,
-    LayoutType.page_footer,
-    LayoutType.page_header,
-    LayoutType.figure,
-    LayoutType.section_header,
-    LayoutType.table,
-    LayoutType.text,
-    LayoutType.title,
+    LayoutType.CAPTION,
+    LayoutType.FOOTNOTE,
+    LayoutType.FORMULA,
+    LayoutType.LIST,
+    LayoutType.PAGE_FOOTER,
+    LayoutType.PAGE_HEADER,
+    LayoutType.FIGURE,
+    LayoutType.SECTION_HEADER,
+    LayoutType.TABLE,
+    LayoutType.TEXT,
+    LayoutType.TITLE,
 ]
 _SUB_CATEGORIES: Mapping[ObjectTypes, Mapping[ObjectTypes, Sequence[ObjectTypes]]] = {
-    LayoutType.caption: {DatasetType.publaynet: [LayoutType.text]},
-    LayoutType.footnote: {DatasetType.publaynet: [LayoutType.text]},
-    LayoutType.formula: {DatasetType.publaynet: [LayoutType.text]},
-    LayoutType.list: {DatasetType.publaynet: [LayoutType.list]},
-    LayoutType.page_footer: {DatasetType.publaynet: [LayoutType.text]},
-    LayoutType.page_header: {DatasetType.publaynet: [LayoutType.title]},
-    LayoutType.figure: {DatasetType.publaynet: [LayoutType.figure]},
-    LayoutType.section_header: {DatasetType.publaynet: [LayoutType.title]},
-    LayoutType.table: {DatasetType.publaynet: [LayoutType.table]},
-    LayoutType.text: {DatasetType.publaynet: [LayoutType.text]},
-    LayoutType.title: {DatasetType.publaynet: [LayoutType.title]},
+    LayoutType.CAPTION: {DatasetType.PUBLAYNET: [LayoutType.TEXT]},
+    LayoutType.FOOTNOTE: {DatasetType.PUBLAYNET: [LayoutType.TEXT]},
+    LayoutType.FORMULA: {DatasetType.PUBLAYNET: [LayoutType.TEXT]},
+    LayoutType.LIST: {DatasetType.PUBLAYNET: [LayoutType.LIST]},
+    LayoutType.PAGE_FOOTER: {DatasetType.PUBLAYNET: [LayoutType.TEXT]},
+    LayoutType.PAGE_HEADER: {DatasetType.PUBLAYNET: [LayoutType.TITLE]},
+    LayoutType.FIGURE: {DatasetType.PUBLAYNET: [LayoutType.FIGURE]},
+    LayoutType.SECTION_HEADER: {DatasetType.PUBLAYNET: [LayoutType.TITLE]},
+    LayoutType.TABLE: {DatasetType.PUBLAYNET: [LayoutType.TABLE]},
+    LayoutType.TEXT: {DatasetType.PUBLAYNET: [LayoutType.TEXT]},
+    LayoutType.TITLE: {DatasetType.PUBLAYNET: [LayoutType.TITLE]},
 }
 
 
 @dataset_registry.register("doclaynet")
 class DocLayNet(DatasetBase):
     """
-    DocLayNetSeq
+    `DocLayNet`
     """
 
     @classmethod
     def _info(cls) -> DatasetInfo:
-        return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, splits=_SPLITS, type=_TYPE, url=_URL)
+        return DatasetInfo(
+            name=_NAME,
+            short_description=_SHORT_DESCRIPTION,
+            description=_DESCRIPTION,
+            license=_LICENSE,
+            splits=_SPLITS,
+            type=_TYPE,
+            url=_URL,
+        )
 
     def _categories(self) -> DatasetCategories:
         return DatasetCategories(init_categories=_INIT_CATEGORIES, init_sub_categories=_SUB_CATEGORIES)
 
-    def _builder(self) -> "DocLayNetBuilder":
+    def _builder(self) -> DocLayNetBuilder:
         return DocLayNetBuilder(location=_LOCATION, annotation_files=_ANNOTATION_FILES)
 
 
 class DocLayNetBuilder(DataFlowBaseBuilder):
     """
-    DocLayNetBuilder dataflow builder
+    `DocLayNetBuilder` dataflow builder
     """
 
     def build(self, **kwargs: Union[str, int]) -> DataFlow:
@@ -123,15 +134,14 @@ class DocLayNetBuilder(DataFlowBaseBuilder):
         Returns a dataflow from which you can stream datapoints of images. The following arguments affect the returns
         of the dataflow:
 
-        `split:` Split of the dataset. Can be `train`,`val` or `test`. Default: `val`
+        Args:
+            kwargs: (split) Split of the dataset. Can be `train`,`val` or `test`. Default: `val`
+                    (max_datapoints) Will stop iterating after `max_datapoints`. Default: `None`
+                    (load_image) Will load the image for each datapoint.  Default: `False`
+                    (fake_score) Will add a fake score so that annotations look like predictions
 
-        `max_datapoints:` Will stop iterating after max_datapoints. Default: None
-
-        `load_image:` Will load the image for each datapoint.  Default: False
-
-        `fake_score:` Will add a fake score so that annotations look like predictions
-
-        :return: dataflow
+        Returns:
+            Dataflow
         """
         split = str(kwargs.get("split", "val"))
         max_datapoints = kwargs.get("max_datapoints")
@@ -161,7 +171,7 @@ class DocLayNetBuilder(DataFlowBaseBuilder):
                 filter_empty_image=True,
                 fake_score=fake_score,
                 coarse_mapping={1: 10, 2: 10, 3: 10, 4: 4, 5: 10, 6: 11, 7: 7, 8: 11, 9: 9, 10: 10, 11: 11},
-                coarse_sub_cat_name=DatasetType.publaynet,
+                coarse_sub_cat_name=DatasetType.PUBLAYNET,
             ),
         )
 
@@ -185,14 +195,14 @@ class DocLayNetBuilder(DataFlowBaseBuilder):
 
 
 _NAME_SEQ = "doclaynet-seq"
-_TYPE_SEQ = DatasetType.sequence_classification
+_TYPE_SEQ = DatasetType.SEQUENCE_CLASSIFICATION
 _INIT_CATEGORIES_SEQ = [
-    DocumentType.financial_report,
-    DocumentType.scientific_publication,
-    DocumentType.laws_and_regulations,
-    DocumentType.government_tenders,
-    DocumentType.manuals,
-    DocumentType.patents,
+    DocumentType.FINANCIAL_REPORT,
+    DocumentType.SCIENTIFIC_PUBLICATION,
+    DocumentType.LAWS_AND_REGULATIONS,
+    DocumentType.GOVERNMENT_TENDERS,
+    DocumentType.MANUALS,
+    DocumentType.PATENTS,
 ]
 
 
@@ -209,7 +219,7 @@ class DocLayNetSeq(DatasetBase):
     def _categories(self) -> DatasetCategories:
         return DatasetCategories(init_categories=_INIT_CATEGORIES_SEQ)
 
-    def _builder(self) -> "DocLayNetSeqBuilder":
+    def _builder(self) -> DocLayNetSeqBuilder:
         return DocLayNetSeqBuilder(location=_LOCATION, annotation_files=_ANNOTATION_FILES)
 
 
@@ -223,11 +233,14 @@ class DocLayNetSeqBuilder(DataFlowBaseBuilder):
         Returns a dataflow from which you can stream datapoints of images. The following arguments affect the returns
         of the dataflow:
 
-        `split:` Split of the dataset. Can be `train`, `val` or `test`. Default: `val`
-        `max_datapoints:` Will stop iterating after max_datapoints. Default: `None`
-        `load_image:` Will load the image for each datapoint.  Default: `False`
+        Args:
+            kwargs:
+                (split) Split of the dataset. Can be `train`, `val` or `test`. Default: `val`
+                (max_datapoints) Will stop iterating after `max_datapoints`. Default: `None`
+                (load_image) Will load the image for each datapoint. Default: `False`
 
-        :return: dataflow
+        Returns:
+            Dataflow
         """
         split = str(kwargs.get("split", "val"))
         max_datapoints = kwargs.get("max_datapoints")
@@ -244,22 +257,22 @@ class DocLayNetSeqBuilder(DataFlowBaseBuilder):
         df = MapDataComponent(df, lambda dp: self.get_workdir() / "PNG" / dp, "file_name")
 
         @curry
-        def _map_to_image(dp: JsonDict, load_img: bool) -> Image:
+        def _map_to_image(dp: CocoDatapointDict, load_img: bool) -> Image:
             image = Image(location=dp["file_name"], file_name=os.path.split(dp["file_name"])[1])
             image.image = load_image_from_file(image.location)
-            summary = SummaryAnnotation()
+            summary = CategoryAnnotation(category_name=SummaryType.SUMMARY)
             label_to_category_name = {
-                "financial_reports": DocumentType.financial_report,
-                "scientific_articles": DocumentType.scientific_publication,
-                "laws_and_regulations": DocumentType.laws_and_regulations,
-                "government_tenders": DocumentType.government_tenders,
-                "manuals": DocumentType.manuals,
-                "patents": DocumentType.patents,
+                "financial_reports": DocumentType.FINANCIAL_REPORT,
+                "scientific_articles": DocumentType.SCIENTIFIC_PUBLICATION,
+                "laws_and_regulations": DocumentType.LAWS_AND_REGULATIONS,
+                "government_tenders": DocumentType.GOVERNMENT_TENDERS,
+                "manuals": DocumentType.MANUALS,
+                "patents": DocumentType.PATENTS,
             }
             categories_dict = self.categories.get_categories(init=True, name_as_key=True)
             category_name = label_to_category_name[dp["doc_category"]]
             summary.dump_sub_category(
-                PageType.document_type,
+                PageType.DOCUMENT_TYPE,
                 CategoryAnnotation(category_name=category_name, category_id=categories_dict[category_name]),
             )
             image.summary = summary
@@ -273,15 +286,14 @@ class DocLayNetSeqBuilder(DataFlowBaseBuilder):
         if self.categories.is_filtered():
             df = MapData(
                 df,
-                filter_summary({PageType.document_type: self.categories.get_categories(as_dict=False, filtered=True)}),
+                filter_summary({PageType.DOCUMENT_TYPE: self.categories.get_categories(as_dict=False, filtered=True)}),
             )
 
             @curry
-            def _re_map_cat_ids(dp: Image, filtered_categories_name_as_key: Mapping[TypeOrStr, str]) -> Image:
-                if dp.summary:
-                    if PageType.document_type in dp.summary.sub_categories:
-                        summary_cat = dp.summary.get_sub_category(PageType.document_type)
-                        summary_cat.category_id = filtered_categories_name_as_key[summary_cat.category_name]
+            def _re_map_cat_ids(dp: Image, filtered_categories_name_as_key: Mapping[TypeOrStr, int]) -> Image:
+                if PageType.DOCUMENT_TYPE in dp.summary.sub_categories:
+                    summary_cat = dp.summary.get_sub_category(PageType.DOCUMENT_TYPE)
+                    summary_cat.category_id = filtered_categories_name_as_key[summary_cat.category_name]
                 return dp
 
             df = MapData(df, _re_map_cat_ids(self.categories.get_categories(filtered=True, name_as_key=True)))
