@@ -16,12 +16,12 @@
 # limitations under the License.
 
 """
-Module for Accuracy metric
+Accuracy metrics (micro, macro, F1 and per label) for classification tasks.
 """
+
 from collections import Counter
-from typing import Any
 from typing import Counter as TypeCounter
-from typing import Dict, List, Mapping, Optional, Sequence, Tuple, Union
+from typing import Mapping, Optional, Sequence, Union
 
 import numpy as np
 from numpy import float32, int32
@@ -32,10 +32,10 @@ from termcolor import colored
 from ..dataflow import DataFlow
 from ..datasets.info import DatasetCategories
 from ..mapper.cats import image_to_cat_id
-from ..utils.detection_types import JsonDict
 from ..utils.file_utils import Requirement
-from ..utils.logger import logger
+from ..utils.logger import LoggingRecord, logger
 from ..utils.settings import ObjectTypes, TypeOrStr, get_type
+from ..utils.types import MetricResults
 from .base import MetricBase
 from .registry import metric_registry
 
@@ -54,7 +54,7 @@ __all__ = [
 
 def _mask_some_gt_and_pr_labels(
     np_label_gt: NDArray[int32], np_label_pr: NDArray[int32], masks: Sequence[int]
-) -> Tuple[NDArray[int32], NDArray[int32]]:
+) -> tuple[NDArray[int32], NDArray[int32]]:
     if len(np_label_gt) != len(masks):
         raise ValueError(f"length of label_gt ({len(np_label_gt)}) and masks ({len(masks)}) must be equal")
     np_masks = np.asarray(masks)
@@ -74,20 +74,25 @@ def _confusion(np_label_gt: NDArray[int32], np_label_pr: NDArray[int32]) -> NDAr
 
 def accuracy(label_gt: Sequence[int], label_predictions: Sequence[int], masks: Optional[Sequence[int]] = None) -> float:
     """
-    Calculates the accuracy given predictions and labels. Ignores masked indices. Uses
-    `sklearn.metrics.accuracy_score`
+    Calculates the accuracy given predictions and labels. Ignores masked indices.
+    Uses `sklearn.metrics.accuracy_score`
 
-    :param label_gt: List of ground truth labels
-    :param label_predictions: List of predictions. Must have the same length as label_gt
-    :param masks: An optional list with masks to ignore some samples.
+    Args:
+        label_gt: List of ground truth labels
+        label_predictions: List of predictions. Must have the same length as label_gt
+        masks: An optional list with masks to ignore some samples
 
-    :return: Accuracy score with only unmasked values to be considered
+    Returns:
+        Accuracy score with only unmasked values considered
+
+    Raises:
+        ValueError: If lengths of label_gt and label_predictions are not equal
     """
 
     np_label_gt, np_label_pr = np.asarray(label_gt), np.asarray(label_predictions)
     if len(np_label_gt) != len(np_label_pr):
         raise ValueError(
-            f"length of label_gt ({len(np_label_gt)}) and label_predictions" f" ({len(np_label_pr)}) must be equal"
+            f"length label_gt: {len(np_label_gt)}, length label_predictions: ({len(np_label_pr)}) but must be equal"
         )
     if masks is not None:
         np_label_gt, np_label_pr = _mask_some_gt_and_pr_labels(np_label_gt, np_label_pr, masks)
@@ -100,13 +105,15 @@ def confusion(
     label_gt: Sequence[int], label_predictions: Sequence[int], masks: Optional[Sequence[int]] = None
 ) -> NDArray[int32]:
     """
-    Calculates the accuracy matrix given the predictions and labels. Ignores masked indices.
+    Calculates the confusion matrix given the predictions and labels.
 
-    :param label_gt: List of ground truth labels
-    :param label_predictions: List of predictions. Must have the same length as label_gt
-    :param masks: List with masks of same length as label_gt.
+    Args:
+        label_gt: List of ground truth labels
+        label_predictions: List of predictions. Must have the same length as label_gt
+        masks: List with masks of same length as label_gt
 
-    :return: numpy array
+    Returns:
+        Confusion matrix as numpy array
     """
 
     np_label_gt, np_label_pr = np.asarray(label_gt), np.asarray(label_predictions)
@@ -124,14 +131,16 @@ def precision(
     micro: bool = False,
 ) -> NDArray[float32]:
     """
-    Calculates the precision for a multi classification problem using a confusion matrix. The output will
-    be the precision by category.
+    Calculates the precision for a multi-classification problem using a confusion matrix.
 
-    :param label_gt: List of ground truth labels
-    :param label_predictions: List of predictions. Must have the same length as label_gt
-    :param masks: List with masks of same length as label_gt.
-    :param micro: If True, it will calculate the micro average precision
-    :return:  numpy array
+    Args:
+        label_gt: List of ground truth labels
+        label_predictions: List of predictions. Must have the same length as label_gt
+        masks: List with masks of same length as label_gt
+        micro: If True, calculates the micro average precision
+
+    Returns:
+        Precision scores by category or micro average
     """
     np_label_gt, np_label_pr = np.asarray(label_gt), np.asarray(label_predictions)
 
@@ -154,14 +163,16 @@ def recall(
     micro: bool = False,
 ) -> NDArray[float32]:
     """
-    Calculates the recall for a multi classification problem using a confusion matrix. The output will
-    be the recall by category.
+    Calculates the recall for a multi-classification problem using a confusion matrix.
 
-    :param label_gt: List of ground truth labels
-    :param label_predictions: List of predictions. Must have the same length as label_gt
-    :param masks: List with masks of same length as label_gt.
-    :param micro: If True, it will calculate the micro average recall
-    :return:  numpy array
+    Args:
+        label_gt: List of ground truth labels
+        label_predictions: List of predictions. Must have the same length as label_gt
+        masks: List with masks of same length as label_gt
+        micro: If True, calculates the micro average recall
+
+    Returns:
+        Recall scores by category or micro average
     """
     np_label_gt, np_label_pr = np.asarray(label_gt), np.asarray(label_predictions)
 
@@ -185,15 +196,17 @@ def f1_score(
     per_label: bool = True,
 ) -> NDArray[float32]:
     """
-    Calculates the recall for a multi classification problem using a confusion matrix. The output will
-    be the recall by category.
+    Calculates the `F1` score for a multi-classification problem.
 
-    :param label_gt: List of ground truth labels
-    :param label_predictions: List of predictions. Must have the same length as label_gt
-    :param masks: List with masks of same length as label_gt.
-    :param micro: If True, it will calculate the micro average f1 score
-    :param per_label: If True, it will return the f1 score per label, otherwise will return the mean of all f1's
-    :return:  numpy array
+    Args:
+        label_gt: List of ground truth labels
+        label_predictions: List of predictions. Must have the same length as label_gt
+        masks: List with masks of same length as label_gt
+        micro: If True, calculates the micro average f1 score
+        per_label: If True, returns the f1 score per label, otherwise returns the mean of all f1's
+
+    Returns:
+        `F1` scores by category, micro average, or mean value
     """
 
     np_precision = precision(label_gt, label_predictions, masks, micro)
@@ -206,7 +219,13 @@ def f1_score(
 
 class ClassificationMetric(MetricBase):
     """
-    Metric induced by `accuracy`
+    Base metric class for classification metrics.
+
+    Attributes:
+        mapper: Function to map images to `category_id`
+        _cats: Optional sequence of `ObjectTypes`
+        _sub_cats: Optional mapping of object types to object types or sequences of `ObjectTypes`
+        _summary_sub_cats: Optional sequence of `ObjectTypes` for summary
     """
 
     mapper = image_to_cat_id
@@ -217,8 +236,7 @@ class ClassificationMetric(MetricBase):
     @classmethod
     def dump(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> Tuple[Any, Any]:
-
+    ) -> tuple[dict[str, list[int]], dict[str, list[int]]]:
         dataflow_gt.reset_state()
         dataflow_predictions.reset_state()
 
@@ -226,17 +244,17 @@ class ClassificationMetric(MetricBase):
         if cls._cats is None and cls._sub_cats is None:
             cls._cats = categories.get_categories(as_dict=False, filtered=True)
         mapper_with_setting = cls.mapper(cls._cats, cls._sub_cats, cls._summary_sub_cats)
-        labels_gt: Dict[str, List[int]] = {}
-        labels_predictions: Dict[str, List[int]] = {}
+        labels_gt: dict[str, list[int]] = {}
+        labels_predictions: dict[str, list[int]] = {}
 
         # returned images of gt and predictions are likely not in the same order. We therefore first stream all data
         # into a dict and generate our result vectors thereafter.
         labels_per_image_gt = {}
         labels_per_image_predictions = {}
         for dp_gt, dp_pd in zip(dataflow_gt, dataflow_predictions):
-            dp_labels_gt, image_id_gt = mapper_with_setting(dp_gt)
+            dp_labels_gt, image_id_gt = mapper_with_setting(dp_gt)  # pylint: disable=E1102
             labels_per_image_gt[image_id_gt] = dp_labels_gt
-            dp_labels_predictions, image_id_pr = mapper_with_setting(dp_pd)
+            dp_labels_predictions, image_id_pr = mapper_with_setting(dp_pd)  # pylint: disable=E1102
             labels_per_image_predictions[image_id_pr] = dp_labels_predictions
 
         for image_id, dp_labels_gt in labels_per_image_gt.items():
@@ -254,8 +272,7 @@ class ClassificationMetric(MetricBase):
     @classmethod
     def get_distance(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> List[JsonDict]:
-
+    ) -> list[MetricResults]:
         labels_gt, labels_pr = cls.dump(dataflow_gt, dataflow_predictions, categories)
 
         results = []
@@ -282,20 +299,20 @@ class ClassificationMetric(MetricBase):
         summary_sub_category_names: Optional[Union[TypeOrStr, Sequence[TypeOrStr]]] = None,
     ) -> None:
         """
-        Set categories that are supposed to be evaluated. If sub_categories have to be considered then they need to be
-        passed explicitly.
+        Set categories that are supposed to be evaluated.
 
-        **Example:**
+        If `sub_categories` have to be considered, they need to be passed explicitly.
 
-            You want to evaluate sub_cat1, sub_cat2 of cat1 and sub_cat3 of cat2. Set
+        Example:
+            ```python
+            # Evaluate sub_cat1, sub_cat2 of cat1 and sub_cat3 of cat2
+            set_categories(sub_category_names={cat1: [sub_cat1, sub_cat2], cat2: sub_cat3})
+            ```
 
-                 sub_category_names = {cat1: [sub_cat1, sub_cat2], cat2: sub_cat3}
-
-
-        :param category_names: List of category names
-        :param sub_category_names: Dict of categories and their sub categories that are supposed to be evaluated,
-                                   e.g. {"FOO": ["bak","baz"]} will evaluate "bak" and "baz"
-        :param summary_sub_category_names: string or list of summary sub categories
+        Args:
+            category_names: List of category names
+            sub_category_names: Dict of categories and their sub categories to be evaluated
+            summary_sub_category_names: String or list of summary sub categories
         """
 
         if category_names is not None:
@@ -341,19 +358,21 @@ class ClassificationMetric(MetricBase):
 
         if cls._cats is None and cls._sub_cats is None and cls._summary_sub_cats is None:
             logger.warning(
-                "Accuracy metric has not correctly been set up: No category, sub category or summary has been "
-                "defined, therefore it is undefined what to evaluate."
+                LoggingRecord(
+                    "Accuracy metric has not correctly been set up: No category, sub category or summary has been "
+                    "defined, therefore it is undefined what to evaluate."
+                )
             )
 
     @classmethod
-    def get_requirements(cls) -> List[Requirement]:
+    def get_requirements(cls) -> list[Requirement]:
         return []
 
     @property
     def sub_cats(
         self,
     ) -> Optional[Union[Mapping[ObjectTypes, ObjectTypes], Mapping[ObjectTypes, Sequence[ObjectTypes]]]]:
-        """sub cats"""
+        """`sub_cats`"""
         return self._sub_cats
 
     @property
@@ -370,7 +389,7 @@ class ClassificationMetric(MetricBase):
             stralign="center",
             numalign="left",
         )
-        logger.info("%s results:\n %s", cls.name, colored(table, "cyan"))
+        logger.info(LoggingRecord(f"{cls.name} results:\n {colored(table, 'cyan')}"))
 
 
 @metric_registry.register("accuracy")
@@ -395,8 +414,7 @@ class ConfusionMetric(ClassificationMetric):
     @classmethod
     def get_distance(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> List[JsonDict]:
-
+    ) -> list[MetricResults]:
         labels_gt, labels_pr = cls.dump(dataflow_gt, dataflow_predictions, categories)
 
         results = []
@@ -408,10 +426,10 @@ class ConfusionMetric(ClassificationMetric):
                     results.append(
                         {
                             "key": key.value if isinstance(key, ObjectTypes) else key,
-                            "category_id_gt": row_number,
+                            "category_id": row_number,
                             "category_id_pr": col_number,
                             "val": float(val),
-                            "num_samples_gt": number_labels[row_number],
+                            "num_samples": number_labels[row_number],
                         }
                     )
         cls._results = results
@@ -421,12 +439,12 @@ class ConfusionMetric(ClassificationMetric):
     def print_result(cls) -> None:
         data = {}
         for entry in cls._results:
-            if entry["category_id_gt"] not in data:
-                data[entry["category_id_gt"]] = [entry["category_id_gt"], entry["val"]]
+            if entry["category_id"] not in data:
+                data[entry["category_id"]] = [entry["category_id"], entry["val"]]
             else:
-                data[entry["category_id_gt"]].append(entry["val"])
+                data[entry["category_id"]].append(entry["val"])
 
-        header = ["predictions -> \n  ground truth |\n              v"] + list(data.keys())
+        header = ["predictions -> \n  ground truth |\n              v"] + list(list(str(element) for element in data))
         table = tabulate([data[k] for k, _ in enumerate(data, 1)], headers=header, tablefmt="pipe")
         logger.info("Confusion matrix: \n %s", colored(table, "cyan"))
 
@@ -443,8 +461,7 @@ class PrecisionMetric(ClassificationMetric):
     @classmethod
     def get_distance(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> List[JsonDict]:
-
+    ) -> list[MetricResults]:
         labels_gt, labels_pr = cls.dump(dataflow_gt, dataflow_predictions, categories)
 
         results = []
@@ -477,7 +494,7 @@ class RecallMetric(PrecisionMetric):
 @metric_registry.register("f1")
 class F1Metric(PrecisionMetric):
     """
-    Metric induced by `f1_score`. Will calculate the f1 per category
+    Metric induced by `f1_score`. Will calculate the F1 per category
     """
 
     name = "F1"
@@ -496,8 +513,7 @@ class PrecisionMetricMicro(ClassificationMetric):
     @classmethod
     def get_distance(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> List[JsonDict]:
-
+    ) -> list[MetricResults]:
         labels_gt, labels_pr = cls.dump(dataflow_gt, dataflow_predictions, categories)
 
         results = []
@@ -527,7 +543,7 @@ class RecallMetricMicro(PrecisionMetricMicro):
 @metric_registry.register("f1_micro")
 class F1MetricMicro(PrecisionMetricMicro):
     """
-    Metric induced by `f1_score`. Will calculate the micro average f1
+    Metric induced by `f1_score`. Will calculate the micro average F1
     """
 
     name = "Micro F1"
