@@ -13,35 +13,41 @@
 # Apache 2.0 License for more details.
 
 """
-Tree distance similarity metric taken from <https://github.com/ibm-aur-nlp/PubTabNet/blob/master/src/metric.py>
+Tree distance similarity (TEDS) metric
+
+Taken from <https://github.com/ibm-aur-nlp/PubTabNet/blob/master/src/metric.py>
 """
 
 import statistics
 from collections import defaultdict, deque
-from typing import Any, List, Optional, Tuple
+from typing import Any, Callable, Optional
+
+from lazy_imports import try_import
 
 from ..dataflow import DataFlow, DataFromList, MapData, MultiThreadMapData
+from ..datapoint.image import Image
 from ..datapoint.view import Page
 from ..datasets.base import DatasetCategories
-from ..utils.detection_types import JsonDict
-from ..utils.file_utils import (
-    Requirement,
-    apted_available,
-    distance_available,
-    get_apted_requirement,
-    get_distance_requirement,
-    get_lxml_requirement,
-    lxml_available,
-)
-from ..utils.logger import logger
+from ..utils.file_utils import Requirement, get_apted_requirement, get_distance_requirement, get_lxml_requirement
+from ..utils.logger import LoggingRecord, logger
 from ..utils.settings import LayoutType
+from ..utils.types import MetricResults
 from .base import MetricBase
 from .registry import metric_registry
 
-if distance_available() and lxml_available() and apted_available():
-    import distance  # type: ignore
+with try_import() as ap_import_guard:
     from apted import APTED, Config  # type: ignore
     from apted.helpers import Tree  # type: ignore
+
+
+if not ap_import_guard.is_successful():
+    from ..utils.mocks import Config, Tree
+
+
+with try_import() as ds_import_guard:
+    import distance  # type: ignore
+
+with try_import() as lx_import_guard:
     from lxml import etree
 
 
@@ -56,7 +62,7 @@ class TableTree(Tree):
         tag: str,
         colspan: Optional[int] = None,
         rowspan: Optional[int] = None,
-        content: Optional[List[str]] = None,
+        content: Optional[list[str]] = None,
     ) -> None:
         self.tag = tag
         self.colspan = colspan
@@ -77,7 +83,8 @@ class TableTree(Tree):
 
 class CustomConfig(Config):
     """
-    CustomConfig for calculating APTED tree edit distance. Check APTED docs for more information
+    `CustomConfig` for calculating `APTED` tree edit distance.
+    Check APTED docs for more information
     """
 
     @staticmethod
@@ -86,7 +93,7 @@ class CustomConfig(Config):
         return max(map(len, sequences))
 
     def normalized_distance(self, *sequences: Any) -> float:
-        """Get distance from 0 to 1"""
+        """Get distance from `0` to `1`"""
         return float(distance.levenshtein(*sequences)) / self.maximum(*sequences)
 
     def rename(self, node1: Any, node2: Any) -> float:
@@ -100,11 +107,11 @@ class CustomConfig(Config):
 
 
 class TEDS:
-    """Tree Edit Distance based Similarity"""
+    """Tree Edit Distance similarity"""
 
     def __init__(self, structure_only: bool = False):
         self.structure_only = structure_only
-        self.__tokens__: List[str] = []
+        self.__tokens__: list[str] = []
 
     def tokenize(self, node: TableTree) -> None:
         """Tokenizes table cells"""
@@ -119,7 +126,7 @@ class TEDS:
             self.__tokens__ += list(node.tail)
 
     def load_html_tree(self, node: TableTree, parent: Optional[TableTree] = None) -> Optional[TableTree]:
-        """Converts HTML tree to the format required by apted"""
+        """Converts `HTML` tree to the format required by APTED"""
         global __tokens__  # pylint: disable = W0602
         if node.tag == "td":
             if self.structure_only:
@@ -146,10 +153,18 @@ class TEDS:
             return new_node
         return None
 
-    def evaluate(self, inputs: Tuple[str, str]) -> float:
-        """Computes TEDS score between the prediction and the ground truth of a
-        given sample
+    def evaluate(self, inputs: tuple[str, str]) -> float:
         """
+        Computes TEDS score between the prediction and the ground truth of a
+        given sample
+
+        Args:
+            inputs: A tuple of ground truth and prediction in xml format
+
+        Returns:
+            A float value between 0.0 and 1.0, where 1.0 means perfect match
+        """
+
         ground_truth, pred = inputs[0], inputs[1]
         if (not pred) or (not ground_truth):
             return 0.0
@@ -157,12 +172,18 @@ class TEDS:
         try:
             ground_truth_tr = etree.XML(ground_truth, parser)
         except etree.XMLSyntaxError:
-            logger.info("SyntaxError while xml parsing ground truth. Sample will be removed", {"xml_gt": ground_truth})
+            logger.info(
+                LoggingRecord(
+                    "SyntaxError while xml parsing ground truth. Sample will be removed", {"xml_gt": ground_truth}
+                )
+            )
             return -1.0
         try:
             pred_tr = etree.XML(pred, parser)
         except etree.XMLSyntaxError:
-            logger.info("SyntaxError while xml parsing prediction. Sample will be removed", {"xml_pr": pred})
+            logger.info(
+                LoggingRecord("SyntaxError while xml parsing prediction. Sample will be removed", {"xml_pr": pred})
+            )
             return -1.0
 
         etree.strip_tags(pred_tr)
@@ -178,11 +199,16 @@ class TEDS:
         return 0.0
 
 
-def teds_metric(gt_list: List[str], predict_list: List[str], structure_only: bool) -> Tuple[float, int]:
+def teds_metric(gt_list: list[str], predict_list: list[str], structure_only: bool) -> tuple[float, int]:
     """
     Computes tree edit distance score (TEDS) between the prediction and the ground truth of a batch of samples. The
-    approach to measure similarity of tables by means of their html representation has been adovacated in
-    <https://arxiv.org/abs/1911.10683> .
+    approach to measure similarity of tables by means of their html representation has been advocated in
+    <https://arxiv.org/abs/1911.10683>
+
+    Args:
+        gt_list: A list of ground truth samples in `xml` format
+        predict_list: A list of predictions in `xml` format
+        structure_only: If `True`, only the structure of the table is considered, but no text
 
     """
     teds = TEDS(structure_only=structure_only)
@@ -207,18 +233,20 @@ def teds_metric(gt_list: List[str], predict_list: List[str], structure_only: boo
 @metric_registry.register("teds")
 class TedsMetric(MetricBase):
     """
-    Metric induced by `teds`
+    Metric induced by `TEDS`
     """
 
     metric = teds_metric  # type: ignore
-    mapper = Page.from_image  # type: ignore
+    mapper: Callable[[Image, LayoutType, list[LayoutType]], Page] = Page.from_image
+    text_container: LayoutType = LayoutType.WORD
+    floating_text_block_categories = [LayoutType.TABLE]
+
     structure_only = False
 
     @classmethod
     def dump(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> Tuple[List[str], List[str]]:
-
+    ) -> tuple[list[str], list[str]]:
         dataflow_gt.reset_state()
         dataflow_predictions.reset_state()
 
@@ -226,11 +254,11 @@ class TedsMetric(MetricBase):
         gt_dict = defaultdict(list)
         pred_dict = defaultdict(list)
         for dp_gt, dp_pred in zip(dataflow_gt, dataflow_predictions):
-            page_gt = cls.mapper(dp_gt, LayoutType.word, [LayoutType.table])  # type: ignore
+            page_gt = cls.mapper(dp_gt, cls.text_container, cls.floating_text_block_categories)
             for table in page_gt.tables:
                 gt_dict[page_gt.image_id].append(table.html)
 
-            page_pred = cls.mapper(dp_pred, LayoutType.word, [LayoutType.table])  # type: ignore
+            page_pred = cls.mapper(dp_pred, cls.text_container, cls.floating_text_block_categories)
             for table in page_pred.tables:
                 pred_dict[page_pred.image_id].append(table.html)
 
@@ -240,17 +268,17 @@ class TedsMetric(MetricBase):
             gt_list.extend(gt_dict[sample])
             pred_list.extend(pred_dict[sample])
 
-        return gt_list, pred_list
+        return gt_list, pred_list  # type: ignore
 
     @classmethod
     def get_distance(
         cls, dataflow_gt: DataFlow, dataflow_predictions: DataFlow, categories: DatasetCategories
-    ) -> List[JsonDict]:
+    ) -> list[MetricResults]:
         html_gt_list, html_pr_list = cls.dump(dataflow_gt, dataflow_predictions, categories)
 
         score, num_samples = cls.metric(html_gt_list, html_pr_list, cls.structure_only)  # type: ignore
         return [{"teds_score": score, "num_samples": num_samples}]
 
     @classmethod
-    def get_requirements(cls) -> List[Requirement]:
+    def get_requirements(cls) -> list[Requirement]:
         return [get_apted_requirement(), get_distance_requirement(), get_lxml_requirement()]
