@@ -16,14 +16,15 @@
 # limitations under the License.
 
 """
-Contains everything that is related to transformation between datapoints
+# Transformation functions for datapoints
 """
-from typing import Callable, Optional
+from typing import Callable
 
-from ..datapoint.image import Image
-from ..utils.file_utils import detectron2_available, pytorch_available, transformers_available
 from .cats import *
 from .cocostruct import *
+from .d2struct import *
+from .hfstruct import *
+from .laylmstruct import *
 from .maputils import *
 from .match import *
 from .misc import *
@@ -33,13 +34,5 @@ from .pubstruct import *
 from .tpstruct import *
 from .xfundstruct import *
 
-if detectron2_available() and pytorch_available():
-    from .d2struct import *
-
-if pytorch_available() and transformers_available():
-    from .hfstruct import *
-    from .laylmstruct import *
-
-
 # Mapper
 Mapper = Callable[[Image], Optional[Image]]
