@@ -45,136 +45,40 @@ with try_import() as pil_import_guard:
 
 __all__ = ["draw_boxes", "interactive_imshow", "viz_handler"]
 
-_COLORS = (
-    np.array(
-        [
-            0.667,
-            0.333,
-            0.500,
-            0.667,
-            0.667,
-            0.500,
-            0.667,
-            1.000,
-            0.500,
-            1.000,
-            0.000,
-            0.500,
-            1.000,
-            0.333,
-            0.500,
-            1.000,
-            0.667,
-            0.500,
-            1.000,
-            1.000,
-            0.500,
-            0.000,
-            0.333,
-            1.000,
-            0.000,
-            0.667,
-            1.000,
-            0.000,
-            1.000,
-            1.000,
-            0.333,
-            0.000,
-            1.000,
-            0.333,
-            0.333,
-            1.000,
-            0.333,
-            0.667,
-            1.000,
-            0.333,
-            1.000,
-            1.000,
-            0.667,
-            0.000,
-            1.000,
-            0.667,
-            0.333,
-            1.000,
-            0.667,
-            0.667,
-            1.000,
-            0.667,
-            1.000,
-            1.000,
-            1.000,
-            0.000,
-            1.000,
-            1.000,
-            0.333,
-            1.000,
-            1.000,
-            0.667,
-            1.000,
-            0.333,
-            0.000,
-            0.000,
-            0.500,
-            0.000,
-            0.000,
-            0.667,
-            0.000,
-            0.000,
-            0.833,
-            0.000,
-            0.000,
-            1.000,
-            0.000,
-            0.000,
-            0.000,
-            0.167,
-            0.000,
-            0.000,
-            0.333,
-            0.000,
-            0.000,
-            0.500,
-            0.000,
-            0.000,
-            0.667,
-            0.000,
-            0.000,
-            0.833,
-            0.000,
-            0.000,
-            1.000,
-            0.000,
-            0.000,
-            0.000,
-            0.167,
-            0.000,
-            0.000,
-            0.333,
-            0.000,
-            0.000,
-            0.500,
-            0.000,
-            0.000,
-            0.667,
-            0.000,
-            0.000,
-            0.833,
-            0.000,
-            0.000,
-            1.000,
-            0.000,
-            0.000,
-            0.000,
-            0.143,
-            0.143,
-            0.143,
-            0.857,
-            0.857,
-            0.857,
-        ]
-    )
-    .astype(np.float32)
-    .reshape(-1, 3)
+_COLORS = np.array(
+    [
+        [0.75   , 0.1125 , 0.1125],
+        [0.75   , 0.24   , 0.1125],
+        [0.75   , 0.3675 , 0.1125],
+        [0.75   , 0.495  , 0.1125],
+        [0.75   , 0.6225 , 0.1125],
+        [0.75   , 0.75   , 0.1125],
+        [0.6225 , 0.75   , 0.1125],
+        [0.495  , 0.75   , 0.1125],
+        [0.3675 , 0.75   , 0.1125],
+        [0.24   , 0.75   , 0.1125],
+        [0.1125 , 0.75   , 0.1125],
+        [0.1125 , 0.75   , 0.24  ],
+        [0.1125 , 0.75   , 0.3675],
+        [0.1125 , 0.75   , 0.495 ],
+        [0.1125 , 0.75   , 0.6225],
+        [0.1125 , 0.75   , 0.75  ],
+        [0.1125 , 0.6225 , 0.75  ],
+        [0.1125 , 0.495  , 0.75  ],
+        [0.1125 , 0.3675 , 0.75  ],
+        [0.1125 , 0.24   , 0.75  ],
+        [0.1125 , 0.1125 , 0.75  ],
+        [0.24   , 0.1125 , 0.75  ],
+        [0.3675 , 0.1125 , 0.75  ],
+        [0.495  , 0.1125 , 0.75  ],
+        [0.6225 , 0.1125 , 0.75  ],
+        [0.75   , 0.1125 , 0.75  ],
+        [0.75   , 0.1125 , 0.6225],
+        [0.75   , 0.1125 , 0.495 ],
+        [0.75   , 0.1125 , 0.3675],
+        [0.75   , 0.1125 , 0.24  ],
+    ],
+    dtype=float32
 )
 
 
